@@ -116,10 +116,11 @@ class R3sponse(object):
 		msg = None
 		if [message,response] == [None,{}]:
 			raise ValueError("Define either parameter [message:str] or [response:dict].")
-		if response != None:
+		if response != {}:
 			if response["error"] != None: msg = f"Error: {response['error']}"
 			else: msg = response['message']
 		else: msg = message
+		print(msg)
 		print(utils.color.fill(msg))
 		if save: self.__log_to_file__(msg)
 
